==> owncloud-10.4.1.zip: owncloud/apps/files_sharing/l10n/ro.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Partajarea server-server nu este activată pe acest server",
    "The mountpoint name contains invalid characters." : "Numele de montare conţine caractere invalide.",
    "Not allowed to create a federated share with the same user server" : "Nu este permisă crearea unei partajări federalizate cu acelaşi utilizator server",
    "Invalid or untrusted SSL certificate" : "Certificat SSL invalid sau emis de o autoritate care nu se află pe lista celor în care se are încredere",
    "Could not authenticate to remote share, password might be wrong" : "Nu mă pot autentifica la partajarea remote, parola poate fi greşită",
    "Storage not valid" : "Stocarea este invalidă",
    "Couldn't add remote share" : "Nu pot adăuga o partajare remote",
    "Shared with you" : "Partajat cu tine",
    "Shared with others" : "Partajat cu alții",
    "Shared by link" : "Partajat prin link",
    "Uploading..." : "Încărcare",
    "Nothing shared with you yet" : "Nimic nu e partajat cu tine încă",
    "Files and folders others share with you will show up here" : "Fișierele și directoarele partajate cu tine vor apărea aici",
    "Nothing shared yet" : "Nimic partajat încă",
    "Files and folders you share will show up here" : "Fișierele și directoarele pe care le partajezi vor apărea aici",
    "No shared links" : "Nicio legătură partajată",
    "Files and folders you share by link will show up here" : "Fișierele și directoarele pe care le partajezi prin legături vor apărea aici",
    "Remote share" : "Element partajat la distanță",
    "Remote share password" : "Parolă element partajat la distanță",
    "Cancel" : "Anulare",
    "Add remote share" : "Adaugă element partajat la distanță",
    "You can upload into this folder" : "Poți încărca în acest director",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nu s-a găsit nicio instanță ownCloud (versiunea 7 sau mai mare) la {remote}",
    "Invalid ownCloud url" : "URL ownCloud invalid",
    "Share" : "Partajează",
    "Pending" : "În așteptare",
    "Shared by" : "impartite in ",
    "Sharing" : "Partajare",
    "A file or folder has been <strong>shared</strong>" : "Un fișier sau director a fost <strong>partajat</strong>",
    "You shared %1$s with %2$s" : "Ai partajat %1$s cu %2$s",
    "You shared %1$s with group %2$s" : "Ai partajat %1$s cu grupul %2$s",
    "You shared %1$s via link" : "Ai partajat %1$s prin legătură",
    "%2$s shared %1$s with you" : "%2$s a partajat %1$s cu tine",
    "Shared with %2$s" : "Partajat cu %2$s",
    "Shared with %3$s by %2$s" : "Partajat de %2$s cu %3$s",
    "Shared with group %2$s" : "Partajat cu grupul %2$s",
    "Shares" : "Partajări",
    "Share API is disabled" : "API-ul de partajare este dezactivat",
    "Wrong share ID, share doesn't exist" : "ID greșit al elementului partajat, acesta nu există",
    "Could not delete share" : "Nu s-a putut șterge elementul partajat",
    "Please specify a file or folder path" : "Specifică un fișier sau o cale către un director",
    "Wrong path, file/folder doesn't exist" : "Cale greșită, fișierul/directorul nu există",
    "Invalid date, date format must be YYYY-MM-DD" : "Dată invalidă, formatul trebuie să fie AAAA-LL-ZZ",
    "Please specify a valid user" : "Specifică un utilizator valid",
    "Please specify a valid group" : "Specifică un grup valid",
    "Not a directory" : "Nu este un director",
    "Could not lock path" : "Calea nu a putut fi blocată",
    "Accept" : "Accept",
    "Decline" : "Refuză",
    "This share is password-protected" : "Această partajare este protejată cu parolă",
    "The password is wrong. Try again." : "Parola este incorectă. Încercaţi din nou.",
    "Password" : "Parolă",
    "No entries found in this folder" : "Niciun element găsit în acest director",
    "Name" : "Nume",
    "Expiration date" : "Data expirării",
    "Reasons might be:" : "Motive posibile ar fi:",
    "the item was removed" : "acest articol a fost șters",
    "the link expired" : "linkul a expirat",
    "sharing is disabled" : "Partajare este oprită",
    "Download" : "Descarcă",
    "Download %s" : "Descarcă %s",
    "Direct link" : "Legătură directă"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> owncloud-10.16.1.zip: owncloud/apps/files_sharing/l10n/ro.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Partajarea server-server nu este activată pe acest server",
    "The mountpoint name contains invalid characters." : "Numele de montare conţine caractere invalide.",
    "Not allowed to create a federated share with the same user server" : "Nu este permisă crearea unei partajări federalizate cu acelaşi utilizator server",
    "Storage not valid" : "Stocarea este invalidă",
    "Shared with you" : "Partajat cu tine",
    "Shared with others" : "Partajat cu alții",
    "Shared by link" : "Partajat prin link",
    "Uploading..." : "Încărcare",
    "Nothing shared with you yet" : "Nimic nu e partajat cu tine încă",
    "Files and folders others share with you will show up here" : "Fișierele și directoarele partajate cu tine vor apărea aici",
    "Nothing shared yet" : "Nimic partajat încă",
    "Files and folders you share will show up here" : "Fișierele și directoarele pe care le partajezi vor apărea aici",
    "No shared links" : "Nicio legătură partajată",
    "Files and folders you share by link will show up here" : "Fișierele și directoarele pe care le partajezi prin legături vor apărea aici",
    "Cancel" : "Anulare",
    "You can upload into this folder" : "Poți încărca în acest director",
    "Add" : "Adaugă",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nu s-a găsit nicio instanță ownCloud (versiunea 7 sau mai mare) la {remote}",
    "Invalid ownCloud url" : "URL ownCloud invalid",
    "Share" : "Partajează",
    "Pending" : "În așteptare",
    "Shared by" : "impartite in ",
    "Sharing" : "Partajare",
    "A file or folder has been <strong>shared</strong>" : "Un fișier sau director a fost <strong>partajat</strong>",
    "You shared %1$s with %2$s" : "Ai partajat %1$s cu %2$s",
    "You shared %1$s with group %2$s" : "Ai partajat %1$s cu grupul %2$s",
    "You shared %1$s via link" : "Ai partajat %1$s prin legătură",
    "%2$s shared %1$s with you" : "%2$s a partajat %1$s cu tine",
    "Shared with %2$s" : "Partajat cu %2$s",
    "Shared with %3$s by %2$s" : "Partajat de %2$s cu %3$s",
    "Shared with group %2$s" : "Partajat cu grupul %2$s",
    "Shared by %2$s" : "Partajat de %2$s",
    "Shares" : "Partajări",
    "Share API is disabled" : "API-ul de partajare este dezactivat",
    "Wrong share ID, share doesn't exist" : "ID greșit al elementului partajat, acesta nu există",
    "Could not delete share" : "Nu s-a putut șterge elementul partajat",
    "Please specify a file or folder path" : "Specifică un fișier sau o cale către un director",
    "Wrong path, file/folder doesn't exist" : "Cale greșită, fișierul/directorul nu există",
    "Invalid date, date format must be YYYY-MM-DD" : "Dată invalidă, formatul trebuie să fie AAAA-LL-ZZ",
    "Please specify a valid user" : "Specifică un utilizator valid",
    "Please specify a valid group" : "Specifică un grup valid",
    "Could not lock path" : "Calea nu a putut fi blocată",
    "Not a directory" : "Nu este un director",
    "Accept" : "Accept",
    "Decline" : "Refuză",
    "This share is password-protected" : "Această partajare este protejată cu parolă",
    "Password" : "Parolă",
    "The password is wrong. Try again." : "Parola este incorectă. Încercaţi din nou.",
    "Proceed" : "Continuă",
    "No entries found in this folder" : "Niciun element găsit în acest director",
    "Name" : "Nume",
    "Expiration date" : "Data expirării",
    "Reasons might be:" : "Motive posibile ar fi:",
    "the item was removed" : "acest articol a fost șters",
    "the link expired" : "linkul a expirat",
    "sharing is disabled" : "Partajare este oprită",
    "Download" : "Descarcă",
    "Download %s" : "Descarcă %s",
    "Direct link" : "Legătură directă"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
